#
# == Class: mcoconfig::activemq::install
#
# Installs ActiveMQ.
#
# === Parameters
#
# [*os_release*]
#    The OS release to pass into the package manager.
#
# === Authors
#
# David McNicol <david@mcnicks.org>
#
# === Copyright
#
# Copyright 2014 David McNicol
#

class mcoconfig::activemq::install (
  $os_release
) {

  case $::osfamily {
    'Debian', 'Ubuntu': {

      include 'apt'
    
      apt::source { 'puppetlabs':
        location   => 'http://apt.puppetlabs.com',
        release    => $os_release,
        repos      => 'main dependencies',
        key        => '4BD6EC30',
        key_source => 'http://pool.sks-keyservers.net/'
      } ->

      package { 'activemq':
        ensure => 'installed'
      }
    }
    'RedHat': {

      $full_release = "puppetlabs-release-el-${os_release}.noarch.rpm"

      exec { 'install-repo':
        command => "/bin/rpm -ihv http://yum.puppetlabs.com/${full_release}",
        creates => '/etc/yum.repos.d/puppetlabs.repo'
      } ->

      package { 'activemq':
        ensure => 'installed'
      }
    }
    default: {
      fail("OS ${::osfamily} not supported by ${module_name}")
    }
  }
}
