#
# == Class: mcoconfig
#
# Configures an MCollective server.
#
# === Parameters
#
# [*middleware_node*]
#   The FQDN of the middleware host.
#
# [*mcollective_password*]
#   The password for the ActiveMQ mcollective user.
#
# [*mcollective_plugins*]
#   An array of MCollective plugins to enable.
#
# === Examples
#
#  class { "mcoconfig":
#      middleware_node => "puppet.domain.com",
#      mcollective_password => "NNNNNNNN"
#  }
#
# === Authors
#
# David McNicol <david@mcnicks.org>
#
# === Copyright
#
# Copyright 2014 David McNicol
#
class mcoconfig (
  $middleware_node,
  $mcollective_password,
  $mcollective_plugins
) {

  # Configure MCollective.

  class { 'mcollective':
    middleware_hosts    => [ $middleware_node ],
    middleware_user     => 'mcollective',
    middleware_password => $mcollective_password,
    server              => true,
    client              => true,
    middleware_ssl      => true,
    securityprovider    => 'ssl',
    ssl_client_certs    => 'puppet:///mco_clients',
    ssl_ca_cert         => 'puppet:///mco_shared/ca.pem',
    ssl_server_public   => 'puppet:///mco_shared/server_cert.pem',
    ssl_server_private  => 'puppet:///mco_shared/server_key.pem'
  }

  # Install plugins.

  mcollective::plugin { $mcollective_plugins:
    package => true
  }
}
